@@ -112,6 +112,34 @@ class docker_api {
         return $result;
     }
     
+    /**
+     * Pull an image from registry without triggering auto-recreation
+     * Used for manual container recreation where we handle the recreation ourselves
+     * 
+     * @param string $image_name Image name to pull
+     * @return array Result array with success flag
+     */
+    public function pull_image_manual($image_name) {
+        $result = dockerApiRequest('POST', "/images/create?fromImage=" . urlencode($image_name));
+        
+        if ($result['success']) {
+            // Update last pull time in database using mysqlmgmt
+            try {
+                require_once('/docker/whp/web/libs/mysqlmgmt.php');
+                $MySQLMgmt = new mysqlmgmt();
+                $MySQLMgmt->updateImagePullTime($image_name);
+            } catch (Exception $e) {
+                error_log('Failed to update image pull time: ' . $e->getMessage());
+            }
+            
+            // Note: We do NOT trigger auto-recreation here since this is manual
+            
+            return ['success' => true, 'message' => 'Image pulled successfully'];
+        }
+        
+        return $result;
+    }
+    
     /**
      * Get image information
      * 
