@@ -473,15 +473,53 @@ class ssl_manager {
         return null;
     }
     
+    /**
+     * Validate domain name format (RFC 1123)
+     *
+     * @param string $domain Domain name to validate
+     * @return bool True if valid
+     */
+    private function isValidDomain($domain) {
+        // RFC 1123 hostname validation
+        $pattern = '/^(?:[a-z0-9](?:[a-z0-9-]{0,61}[a-z0-9])?\.)*[a-z0-9](?:[a-z0-9-]{0,61}[a-z0-9])?$/i';
+        return (bool)preg_match($pattern, $domain) && strlen($domain) <= 253 && strlen($domain) > 0;
+    }
+
+    /**
+     * Validate service name against whitelist
+     *
+     * @param string $service_name Service name to validate
+     * @return bool True if valid
+     */
+    private function isValidServiceName($service_name) {
+        $allowed_services = ['httpd', 'proftpd'];
+        return in_array($service_name, $allowed_services, true);
+    }
+
     /**
      * Enable SSL for system services
-     * 
+     *
      * @param string $service_name Service name (httpd, proftpd, etc.)
      * @param string $domain Domain name for certificate
      * @return array Result array with success/error status
      */
     public function enable_system_service_ssl($service_name, $domain) {
         try {
+            // Validate inputs
+            if (!$this->isValidServiceName($service_name)) {
+                return [
+                    'success' => false,
+                    'error' => 'Invalid service name'
+                ];
+            }
+
+            if (!$this->isValidDomain($domain)) {
+                return [
+                    'success' => false,
+                    'error' => 'Invalid domain name format'
+                ];
+            }
+
             error_log("SSL Manager: Starting SSL enable for system service: {$service_name} with domain: {$domain}");
             
             // Request SSL certificate from HAProxy Manager
@@ -511,9 +549,10 @@ class ssl_manager {
                 sleep(2);
                 
                 // Check if certificate exists in container
-                $check_cmd = "docker exec haproxy-manager test -f {$container_cert_path}";
+                $safe_container_path = escapeshellarg($container_cert_path);
+                $check_cmd = "docker exec haproxy-manager test -f " . $safe_container_path;
                 exec($check_cmd . " 2>&1", $output, $return_code);
-                
+
                 if ($return_code !== 0) {
                     error_log("SSL Manager: Certificate not found in container at {$container_cert_path} (exit code: {$return_code})");
                     return [
@@ -521,16 +560,18 @@ class ssl_manager {
                         'error' => 'Certificate not found in HAProxy container. The certificate may still be generating or there was an issue with the SSL request.'
                     ];
                 }
-                
+
                 // Copy certificate from container to host
-                $copy_cmd = "docker cp haproxy-manager:{$container_cert_path} {$host_cert_path}";
-                $copy_result = shell_exec($copy_cmd . " 2>&1");
-                
-                if (!empty($copy_result)) {
-                    error_log("SSL Manager: Error copying certificate: " . $copy_result);
+                $safe_host_path = escapeshellarg($host_cert_path);
+                $copy_cmd = "docker cp haproxy-manager:" . $safe_container_path . " " . $safe_host_path;
+                exec($copy_cmd . " 2>&1", $copy_output, $copy_return);
+
+                if ($copy_return !== 0) {
+                    $error_msg = implode("\n", $copy_output);
+                    error_log("SSL Manager: Error copying certificate: " . $error_msg);
                     return [
                         'success' => false,
-                        'error' => 'Failed to copy certificate from container: ' . $copy_result
+                        'error' => 'Failed to copy certificate from container'
                     ];
                 }
                 
@@ -770,6 +811,21 @@ SSLCryptoDevice builtin
      */
     public function renew_system_service_ssl($service_name, $domain) {
         try {
+            // Validate inputs
+            if (!$this->isValidServiceName($service_name)) {
+                return [
+                    'success' => false,
+                    'error' => 'Invalid service name'
+                ];
+            }
+
+            if (!$this->isValidDomain($domain)) {
+                return [
+                    'success' => false,
+                    'error' => 'Invalid domain name format'
+                ];
+            }
+
             // Request SSL certificate renewal from HAProxy Manager
             $result = $this->haproxy_manager->renewCertificate($domain);
             
@@ -795,9 +851,10 @@ SSLCryptoDevice builtin
                 sleep(2);
                 
                 // Check if certificate exists in container
-                $check_cmd = "docker exec haproxy-manager test -f {$container_cert_path}";
+                $safe_container_path = escapeshellarg($container_cert_path);
+                $check_cmd = "docker exec haproxy-manager test -f " . $safe_container_path;
                 exec($check_cmd . " 2>&1", $output, $return_code);
-                
+
                 if ($return_code !== 0) {
                     error_log("SSL Manager: Renewed certificate not found in container at {$container_cert_path} (exit code: {$return_code})");
                     return [
@@ -805,16 +862,18 @@ SSLCryptoDevice builtin
                         'error' => 'Renewed certificate not found in HAProxy container. The certificate may still be renewing or there was an issue with the renewal request.'
                     ];
                 }
-                
+
                 // Copy certificate from container to host
-                $copy_cmd = "docker cp haproxy-manager:{$container_cert_path} {$host_cert_path}";
-                $copy_result = shell_exec($copy_cmd . " 2>&1");
-                
-                if (!empty($copy_result)) {
-                    error_log("SSL Manager: Error copying renewed certificate: " . $copy_result);
+                $safe_host_path = escapeshellarg($host_cert_path);
+                $copy_cmd = "docker cp haproxy-manager:" . $safe_container_path . " " . $safe_host_path;
+                exec($copy_cmd . " 2>&1", $copy_output, $copy_return);
+
+                if ($copy_return !== 0) {
+                    $error_msg = implode("\n", $copy_output);
+                    error_log("SSL Manager: Error copying renewed certificate: " . $error_msg);
                     return [
                         'success' => false,
-                        'error' => 'Failed to copy renewed certificate from container: ' . $copy_result
+                        'error' => 'Failed to copy renewed certificate from container'
                     ];
                 }
                 
@@ -861,20 +920,28 @@ SSLCryptoDevice builtin
     
     /**
      * Restart a system service
-     * 
+     *
      * @param string $service_name Service name
+     * @return bool True if successful
      */
     private function restartService($service_name) {
-        switch ($service_name) {
-            case 'httpd':
-                shell_exec('systemctl restart httpd');
-                break;
-            case 'proftpd':
-                shell_exec('systemctl restart proftpd');
-                break;
-            default:
-                error_log("SSL Manager: Unknown service for restart: {$service_name}");
+        // Strict whitelist validation
+        if (!$this->isValidServiceName($service_name)) {
+            $safe_name = preg_replace('/[^a-zA-Z0-9_-]/', '', $service_name);
+            error_log("SSL Manager: Invalid service name attempted: " . $safe_name);
+            return false;
         }
+
+        // Execute restart with error checking
+        exec('systemctl restart ' . escapeshellarg($service_name) . ' 2>&1', $output, $return_code);
+
+        if ($return_code !== 0) {
+            error_log("SSL Manager: Failed to restart {$service_name}: " . implode("\n", $output));
+            return false;
+        }
+
+        error_log("SSL Manager: Successfully restarted {$service_name}");
+        return true;
     }
     
     /**
@@ -996,17 +1063,17 @@ SSLCryptoDevice builtin
     
     /**
      * Get all system service SSL certificates
-     * 
+     *
      * @return array System service SSL certificates
      */
     public function getSystemServiceSSLCertificates() {
         try {
             $stmt = $this->db->query("
-                SELECT * FROM whp.system_ssl_certificates 
+                SELECT * FROM whp.system_ssl_certificates
                 ORDER BY service_name, domain_name
             ");
             $certificates = $stmt->fetchAll();
-            
+
             // Add expiration information for each certificate
             foreach ($certificates as &$cert) {
                 if (!empty($cert['certificate_path']) && file_exists($cert['certificate_path'])) {
@@ -1017,12 +1084,204 @@ SSLCryptoDevice builtin
                     $cert['days_until_expiry'] = null;
                 }
             }
-            
+
             return $certificates;
         } catch (PDOException $e) {
             error_log("SSL Manager: Failed to get system service SSL certificates: " . $e->getMessage());
             return [];
         }
     }
+
+    /**
+     * Refresh system service SSL certificate from HAProxy
+     * This method copies the latest certificate from HAProxy and restarts the service
+     *
+     * @param string $service_name Service name
+     * @param string $domain Domain name
+     * @return array Result array with success/error status
+     */
+    public function refreshSystemServiceSSL($service_name, $domain) {
+        try {
+            // Validate inputs
+            if (!$this->isValidServiceName($service_name)) {
+                return [
+                    'success' => false,
+                    'error' => 'Invalid service name'
+                ];
+            }
+
+            if (!$this->isValidDomain($domain)) {
+                return [
+                    'success' => false,
+                    'error' => 'Invalid domain name format'
+                ];
+            }
+
+            error_log("SSL Manager: Refreshing SSL for system service: {$service_name} with domain: {$domain}");
+
+            // Check if this service/domain is configured
+            $stmt = $this->db->prepare("
+                SELECT * FROM whp.system_ssl_certificates
+                WHERE service_name = ? AND domain_name = ? AND ssl_enabled = 1
+            ");
+            $stmt->execute([$service_name, $domain]);
+            $cert_record = $stmt->fetch();
+
+            if (!$cert_record) {
+                return [
+                    'success' => false,
+                    'error' => "No active SSL configuration found for {$service_name} - {$domain}"
+                ];
+            }
+
+            // Request certificate renewal from HAProxy (this regenerates the PEM file)
+            error_log("SSL Manager: Requesting certificate renewal from HAProxy for {$domain}");
+            $result = $this->haproxy_manager->renewCertificate($domain);
+
+            if (!$result['success']) {
+                error_log("SSL Manager: HAProxy renewal failed: " . ($result['error'] ?? 'Unknown error'));
+                return $result;
+            }
+
+            error_log("SSL Manager: HAProxy renewal successful, copying certificate from container");
+
+            // Create certificate directory if it doesn't exist
+            $cert_dir = "/etc/certs";
+            if (!is_dir($cert_dir)) {
+                if (!mkdir($cert_dir, 0755, true)) {
+                    return [
+                        'success' => false,
+                        'error' => 'Failed to create certificate directory: ' . $cert_dir
+                    ];
+                }
+            }
+
+            // Copy certificate from HAProxy container
+            $container_cert_path = "/etc/haproxy/certs/{$domain}.pem";
+            $host_cert_path = "{$cert_dir}/{$domain}.pem";
+
+            // Wait for the certificate to be regenerated
+            sleep(2);
+
+            // Check if certificate exists in container
+            $safe_container_path = escapeshellarg($container_cert_path);
+            $check_cmd = "docker exec haproxy-manager test -f " . $safe_container_path;
+            exec($check_cmd . " 2>&1", $output, $return_code);
+
+            if ($return_code !== 0) {
+                error_log("SSL Manager: Certificate not found in container at {$container_cert_path}");
+                return [
+                    'success' => false,
+                    'error' => 'Certificate not found in HAProxy container'
+                ];
+            }
+
+            // Copy certificate from container to host
+            $safe_host_path = escapeshellarg($host_cert_path);
+            $copy_cmd = "docker cp haproxy-manager:" . $safe_container_path . " " . $safe_host_path;
+            exec($copy_cmd . " 2>&1", $copy_output, $copy_return);
+
+            if ($copy_return !== 0) {
+                $error_msg = implode("\n", $copy_output);
+                error_log("SSL Manager: Error copying certificate: " . $error_msg);
+                return [
+                    'success' => false,
+                    'error' => 'Failed to copy certificate from container'
+                ];
+            }
+
+            // Verify the certificate file was copied successfully
+            if (!file_exists($host_cert_path)) {
+                return [
+                    'success' => false,
+                    'error' => 'Certificate file was not copied successfully to: ' . $host_cert_path
+                ];
+            }
+
+            // Set proper permissions
+            chmod($host_cert_path, 0600);
+
+            error_log("SSL Manager: Successfully copied certificate to {$host_cert_path}");
+
+            // Update database record
+            $stmt = $this->db->prepare("
+                UPDATE whp.system_ssl_certificates
+                SET last_renewal = CURRENT_TIMESTAMP,
+                    certificate_path = ?,
+                    private_key_path = ?
+                WHERE service_name = ? AND domain_name = ?
+            ");
+            $stmt->execute([$host_cert_path, $host_cert_path, $service_name, $domain]);
+
+            // Restart the service to use the new certificate
+            error_log("SSL Manager: Restarting {$service_name} to apply refreshed certificate");
+            $this->restartService($service_name);
+
+            return [
+                'success' => true,
+                'message' => "SSL certificate refreshed and {$service_name} restarted for {$domain}"
+            ];
+
+        } catch (PDOException $e) {
+            error_log("SSL Manager: Database error during refresh: " . $e->getMessage());
+            return [
+                'success' => false,
+                'error' => 'Database error: ' . $e->getMessage()
+            ];
+        } catch (Exception $e) {
+            error_log("SSL Manager: Error during refresh: " . $e->getMessage());
+            return [
+                'success' => false,
+                'error' => $e->getMessage()
+            ];
+        }
+    }
+
+    /**
+     * Refresh all system service SSL certificates from HAProxy
+     * Used by cron to keep system service certificates up to date
+     *
+     * @return array Result summary
+     */
+    public function refreshAllSystemServiceSSL() {
+        try {
+            $stmt = $this->db->query("
+                SELECT service_name, domain_name
+                FROM whp.system_ssl_certificates
+                WHERE ssl_enabled = 1
+            ");
+            $certificates = $stmt->fetchAll();
+
+            $results = [
+                'total' => count($certificates),
+                'refreshed' => 0,
+                'failed' => 0,
+                'errors' => []
+            ];
+
+            foreach ($certificates as $cert) {
+                error_log("SSL Manager: Processing refresh for {$cert['service_name']} - {$cert['domain_name']}");
+                $result = $this->refreshSystemServiceSSL($cert['service_name'], $cert['domain_name']);
+
+                if ($result['success']) {
+                    $results['refreshed']++;
+                } else {
+                    $results['failed']++;
+                    $results['errors'][] = "{$cert['service_name']} - {$cert['domain_name']}: " . $result['error'];
+                }
+            }
+
+            return $results;
+
+        } catch (PDOException $e) {
+            error_log("SSL Manager: Failed to refresh all system service SSL certificates: " . $e->getMessage());
+            return [
+                'total' => 0,
+                'refreshed' => 0,
+                'failed' => 1,
+                'errors' => ['Database error: ' . $e->getMessage()]
+            ];
+        }
+    }
 }
 ?> 
\ No newline at end of file
