@@ -55,6 +55,40 @@ function whp_getServerData(array $params) {
     }
 }
 
+/**
+ * Get base plan resources from WHMCS product configuration
+ */
+function whp_getBaseResources($params) {
+    // In WHMCS, the base plan resources are stored in the module configuration
+    // These are the values you set in the Module Settings tab for the product
+    // WHMCS passes these as configoption1, configoption2, etc. based on the order in whp_ConfigOptions()
+    
+    // Extract base resources from module configuration
+    // These correspond to the order defined in whp_ConfigOptions() function:
+    // 1. CPU Cores, 2. Memory (MB), 3. Disk Space (MB), 4. Email Accounts, 5. Email Storage (MB)
+    $baseResources = array(
+        'cpu_cores' => floatval($params['configoption1'] ?? 0.5),
+        'memory_mb' => intval($params['configoption2'] ?? 512),
+        'disk_mb' => intval($params['configoption3'] ?? 1000),
+        'email_accounts' => intval($params['configoption4'] ?? 0),
+        'email_storage_mb' => intval($params['configoption5'] ?? 1000),
+    );
+    
+    // Log what we found for debugging
+    logModuleCall('whp', 'getBaseResources', array(
+        'all_params' => array_keys($params),
+        'configoption1_cpu_cores' => $params['configoption1'] ?? 'not set',
+        'configoption2_memory_mb' => $params['configoption2'] ?? 'not set',
+        'configoption3_disk_mb' => $params['configoption3'] ?? 'not set',
+        'configoption4_email_accounts' => $params['configoption4'] ?? 'not set',
+        'configoption5_email_storage_mb' => $params['configoption5'] ?? 'not set',
+        'extracted_base_resources' => $baseResources,
+        'pid' => $params['pid'] ?? 'not set'
+    ), 'Base resource extraction from module configuration');
+    
+    return $baseResources;
+}
+
 /**
  * Define product configuration options.
  */
@@ -106,19 +140,59 @@ function whp_CreateAccount(array $params) {
         $domain = $params['domain'] ?? '';
         $configoptions = $params['configoptions'];
         
+        // Debug logging - log what WHMCS is passing to the module
+        logModuleCall('whp', 'CreateAccount_ConfigOptions', array(
+            'username' => $username,
+            'configoptions_raw' => $configoptions,
+            'all_params_keys' => array_keys($params),
+            'producttype' => $params['producttype'] ?? 'not set',
+            'pid' => $params['pid'] ?? 'not set',
+            'serviceid' => $params['serviceid'] ?? 'not set',
+            'customfields' => $params['customfields'] ?? array()
+        ), 'WHMCS configuration debugging');
+        
+        // Get base plan resources from WHMCS product configuration
+        // These should be set in the product/plan configuration in WHMCS admin
+        $baseResources = whp_getBaseResources($params);
+        
+        // Configurable options are customer upgrades on top of base resources
+        $upgradeResources = array(
+            'cpu_cores' => floatval($configoptions['CPU Cores'] ?? 0),
+            'memory_mb' => intval($configoptions['Memory (MB)'] ?? 0),
+            'disk_mb' => intval($configoptions['Disk Space (MB)'] ?? 0),
+            'email_accounts' => intval($configoptions['Email Accounts'] ?? 0),
+            'email_storage_mb' => intval($configoptions['Email Storage (MB)'] ?? 0),
+        );
+        
+        // Combine base resources + configurable option upgrades
+        $finalResources = array(
+            'cpu_cores' => $baseResources['cpu_cores'] + $upgradeResources['cpu_cores'],
+            'memory_mb' => $baseResources['memory_mb'] + $upgradeResources['memory_mb'],
+            'disk_mb' => $baseResources['disk_mb'] + $upgradeResources['disk_mb'],
+            'email_accounts' => $baseResources['email_accounts'] + $upgradeResources['email_accounts'],
+            'email_storage_mb' => $baseResources['email_storage_mb'] + $upgradeResources['email_storage_mb'],
+        );
+        
         // Prepare API request
         $apiData = array(
             'username' => $username,
             'password' => $password,
-            'resources' => array(
-                'cpu_cores' => floatval($configoptions['CPU Cores'] ?: 0.5),
-                'memory_mb' => intval($configoptions['Memory (MB)'] ?: 512),
-                'disk_mb' => intval($configoptions['Disk Space (MB)'] ?: 1000),
-                'email_accounts' => intval($configoptions['Email Accounts'] ?: 0),
-                'email_storage_mb' => intval($configoptions['Email Storage (MB)'] ?: 1000),
-            ),
+            'resources' => $finalResources,
         );
         
+        // Debug logging - log the resource calculation
+        logModuleCall('whp', 'CreateAccount_ResourceCalculation', array(
+            'base_resources' => $baseResources,
+            'upgrade_resources' => $upgradeResources,
+            'final_resources' => $finalResources
+        ), 'Resource calculation for WHP API');
+        
+        // Debug logging - log what we're sending to WHP
+        logModuleCall('whp', 'CreateAccount_SendingToWHP', array(
+            'username' => $username,
+            'resources_being_sent' => $apiData['resources']
+        ), 'Resources being sent to WHP API');
+        
         // Add domain if provided
         if (!empty($domain)) {
             $apiData['domain'] = $domain;
@@ -240,17 +314,39 @@ function whp_ChangePackage(array $params) {
         $username = $params['username'];
         $configoptions = $params['configoptions'];
         
+        // Get base plan resources from WHMCS product configuration
+        $baseResources = whp_getBaseResources($params);
+        
+        // Configurable options are customer upgrades on top of base resources
+        $upgradeResources = array(
+            'cpu_cores' => floatval($configoptions['CPU Cores'] ?? 0),
+            'memory_mb' => intval($configoptions['Memory (MB)'] ?? 0),
+            'disk_mb' => intval($configoptions['Disk Space (MB)'] ?? 0),
+            'email_accounts' => intval($configoptions['Email Accounts'] ?? 0),
+            'email_storage_mb' => intval($configoptions['Email Storage (MB)'] ?? 0),
+        );
+        
+        // Combine base resources + configurable option upgrades
+        $finalResources = array(
+            'cpu_cores' => $baseResources['cpu_cores'] + $upgradeResources['cpu_cores'],
+            'memory_mb' => $baseResources['memory_mb'] + $upgradeResources['memory_mb'],
+            'disk_mb' => $baseResources['disk_mb'] + $upgradeResources['disk_mb'],
+            'email_accounts' => $baseResources['email_accounts'] + $upgradeResources['email_accounts'],
+            'email_storage_mb' => $baseResources['email_storage_mb'] + $upgradeResources['email_storage_mb'],
+        );
+        
         $apiData = array(
             'username' => $username,
-            'resources' => array(
-                'cpu_cores' => floatval($configoptions['CPU Cores'] ?: 0.5),
-                'memory_mb' => intval($configoptions['Memory (MB)'] ?: 512),
-                'disk_mb' => intval($configoptions['Disk Space (MB)'] ?: 1000),
-                'email_accounts' => intval($configoptions['Email Accounts'] ?: 0),
-                'email_storage_mb' => intval($configoptions['Email Storage (MB)'] ?: 1000),
-            ),
+            'resources' => $finalResources,
         );
         
+        // Debug logging - log the resource calculation
+        logModuleCall('whp', 'ChangePackage_ResourceCalculation', array(
+            'base_resources' => $baseResources,
+            'upgrade_resources' => $upgradeResources,
+            'final_resources' => $finalResources
+        ), 'Resource calculation for package change');
+        
         $response = whp_api_call($serverdata, 'PUT', 'users.php?action=resources', $apiData);
         
         if ($response['status'] === 'success') {
@@ -428,18 +524,40 @@ function whp_update_resources(array $params) {
         $username = $params['username'];
         $configoptions = $params['configoptions'];
         
+        // Get base plan resources from WHMCS product configuration
+        $baseResources = whp_getBaseResources($params);
+        
+        // Configurable options are customer upgrades on top of base resources
+        $upgradeResources = array(
+            'cpu_cores' => floatval($configoptions['CPU Cores'] ?? 0),
+            'memory_mb' => intval($configoptions['Memory (MB)'] ?? 0),
+            'disk_mb' => intval($configoptions['Disk Space (MB)'] ?? 0),
+            'email_accounts' => intval($configoptions['Email Accounts'] ?? 0),
+            'email_storage_mb' => intval($configoptions['Email Storage (MB)'] ?? 0),
+        );
+        
+        // Combine base resources + configurable option upgrades
+        $finalResources = array(
+            'cpu_cores' => $baseResources['cpu_cores'] + $upgradeResources['cpu_cores'],
+            'memory_mb' => $baseResources['memory_mb'] + $upgradeResources['memory_mb'],
+            'disk_mb' => $baseResources['disk_mb'] + $upgradeResources['disk_mb'],
+            'email_accounts' => $baseResources['email_accounts'] + $upgradeResources['email_accounts'],
+            'email_storage_mb' => $baseResources['email_storage_mb'] + $upgradeResources['email_storage_mb'],
+        );
+        
         // Prepare resource update data
         $apiData = array(
             'username' => $username,
-            'resources' => array(
-                'cpu_cores' => floatval($configoptions['CPU Cores'] ?: 0.5),
-                'memory_mb' => intval($configoptions['Memory (MB)'] ?: 512),
-                'disk_mb' => intval($configoptions['Disk Space (MB)'] ?: 1000),
-                'email_accounts' => intval($configoptions['Email Accounts'] ?: 0),
-                'email_storage_mb' => intval($configoptions['Email Storage (MB)'] ?: 1000),
-            ),
+            'resources' => $finalResources,
         );
         
+        // Debug logging - log the resource calculation
+        logModuleCall('whp', 'UpdateResources_ResourceCalculation', array(
+            'base_resources' => $baseResources,
+            'upgrade_resources' => $upgradeResources,
+            'final_resources' => $finalResources
+        ), 'Resource calculation for update resources');
+        
         $response = whp_api_call($serverdata, 'PUT', 'users.php?action=resources', $apiData);
         
         if ($response['status'] === 'success') {
@@ -513,20 +631,31 @@ function whp_update_quota(array $params) {
         $username = $params['username'];
         $configoptions = $params['configoptions'];
         
-        // Update disk quota specifically
-        $diskMb = intval($configoptions['Disk Space (MB)'] ?: 1000);
+        // Get base plan resources from WHMCS product configuration
+        $baseResources = whp_getBaseResources($params);
+        
+        // Calculate final disk quota (base + configurable upgrades)
+        $upgradeDiskMb = intval($configoptions['Disk Space (MB)'] ?? 0);
+        $finalDiskMb = $baseResources['disk_mb'] + $upgradeDiskMb;
         
         $apiData = array(
             'username' => $username,
             'resources' => array(
-                'disk_mb' => $diskMb,
+                'disk_mb' => $finalDiskMb,
             ),
         );
         
+        // Debug logging
+        logModuleCall('whp', 'UpdateQuota_Calculation', array(
+            'base_disk_mb' => $baseResources['disk_mb'],
+            'upgrade_disk_mb' => $upgradeDiskMb,
+            'final_disk_mb' => $finalDiskMb
+        ), 'Disk quota calculation');
+        
         $response = whp_api_call($serverdata, 'PUT', 'users.php?action=resources', $apiData);
         
         if ($response['status'] === 'success') {
-            return 'Disk quota updated successfully to ' . $diskMb . ' MB.';
+            return 'Disk quota updated successfully to ' . $finalDiskMb . ' MB.';
         } else {
             return 'Disk quota update failed: ' . $response['message'];
         }
